package deployer

import (
	"fmt"
	"os"
	"strings"
)

const (
	DEPLOYER_SUFFIX = "-deployer" // The depoyer suffix appended after the project name in gitlab
)

var (
	PROJECT_ROOT     string // example: "/root/go"
	PROJECT_NAME     string // example: "hydra"
	REGISTRY_IMAGE   string // example: "code.electrolab.fr/it/hydra-deployer
	ENVIRONMENT_NAME string // example: "staging"
)

func init() {
	if wd, err := os.Getwd(); err != nil {
		Throw(fmt.Sprintf("Unable to get PROJECT_ROOT: %s", err.Error()))
	} else {
		PROJECT_ROOT = wd
	}
	gitlabProjectName := Env("CI_PROJECT_NAME")
	if !strings.HasSuffix(gitlabProjectName, DEPLOYER_SUFFIX) {
		Throw(fmt.Sprintf("Gitlab deployer project must end with '-deployer' but is '%s'", gitlabProjectName))
	}
	PROJECT_NAME = gitlabProjectName[:len(gitlabProjectName)-len(DEPLOYER_SUFFIX)]
	if s, found := os.LookupEnv("CI_REGISTRY_IMAGE"); !found {
		Throw(fmt.Sprintf("Gitlab docker registry must be enabled for project '%s'", gitlabProjectName))
	} else {
		REGISTRY_IMAGE = s
	}
	if s, found := os.LookupEnv("CI_ENVIRONMENT_NAME"); !found {
		Throw(fmt.Sprintf("gitlab-ci.yml must define an environment", gitlabProjectName))
	} else {
		ENVIRONMENT_NAME = s
	}
}

func Setenv(key string, value string) {
	ThrowIfErr(os.Setenv(key, value))
}

func Env(key string) string {
	value, found := os.LookupEnv(key)
	if !found {
		ThrowIfErr(fmt.Errorf("Expected env key not found: %s", key))
	}
	return value
}
