FROM ubuntu

RUN apt-get update && apt-get upgrade -y --no-install-recommends

RUN apt-get update && \
    apt-get install -y --no-install-recommends \
        apt-transport-https \
        ca-certificates \
        curl \
        gnupg-agent \
        software-properties-common && \
    curl -fsSL https://download.docker.com/linux/ubuntu/gpg | apt-key add - && \
    add-apt-repository "deb [arch=amd64] https://download.docker.com/linux/ubuntu $(lsb_release -cs) stable" && \
    apt-get update && \
    apt-get install -y --no-install-recommends docker-ce docker-ce-cli

RUN curl -L https://github.com/docker/compose/releases/download/1.23.2/docker-compose-$(uname -s)-$(uname -m) -o /usr/local/bin/docker-compose && \
    chmod +x /usr/local/bin/docker-compose

RUN apt-get update && \
    apt-get install -y --no-install-recommends openssl

RUN apt-get update && \
    apt-get install -y --no-install-recommends postgresql-client

RUN apt-get update && \
    apt-get install -y --no-install-recommends ruby

RUN apt-get update && \
    apt-get install -y --no-install-recommends python

########
# Golang begin
########
RUN apt-get update && \
    apt-get install -y --no-install-recommends g++ gcc libc6-dev make pkg-config

ENV GOLANG_VERSION 1.11.5
ENV GOLANG_DOWNLOAD_URL https://golang.org/dl/go$GOLANG_VERSION.linux-amd64.tar.gz
ENV GOLANG_DOWNLOAD_SHA256 ff54aafedff961eb94792487e827515da683d61a5f9482f668008832631e5d25

RUN curl -fsSL "$GOLANG_DOWNLOAD_URL" -o golang.tar.gz \
    && echo "$GOLANG_DOWNLOAD_SHA256  golang.tar.gz" | sha256sum -c - \
    && tar -C /usr/local -xzf golang.tar.gz \
    && rm golang.tar.gz

ENV GOPATH /go
ENV PATH $GOPATH/bin:/usr/local/go/bin:$PATH

RUN mkdir -p "$GOPATH/src" "$GOPATH/bin" && chmod -R 755 "$GOPATH"

########
# Golang end
########

RUN apt-get update && \
    apt-get install -y --no-install-recommends git

RUN apt-get clean && \
    rm -r /var/lib/apt/lists/*

ENV DEPLOYMENT_TARGET ""
ENV DEPLOYMENT_SECRET ""

# Add util to easily run tasks function
RUN go get -u npf.io/gorram

RUN apt-get update && \
    apt-get install -y --no-install-recommends unzip

# Add bitwarden utility
RUN curl -fsSL "https://vault.bitwarden.com/download/?app=cli&platform=linux" -o bitwarden.zip \
    && unzip bitwarden.zip \
    && mv bw /bin/ \
    && rm bitwarden.zip

ADD entrypoint /

# Add and compile ciutil library
ADD ciutil /usr/local/go/src/ciutil
RUN cd /usr/local/go/src/ciutil && find * -type d -exec echo "go install {}" \;

ADD encrypted /encrypted

ENTRYPOINT /bin/sh -c /entrypoint
